# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_common/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_common/common.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.exactpro.th2.common.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cth2_grpc_common/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"%\n\x0c\x43onnectionID\x12\x15\n\rsession_alias\x18\x01 \x01(\t\"w\n\tMessageID\x12$\n\rconnection_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12\x1d\n\tdirection\x18\x02 \x01(\x0e\x32\n.Direction\x12\x10\n\x08sequence\x18\x03 \x01(\x03\x12\x13\n\x0bsubsequence\x18\x04 \x03(\r\"\xe9\x01\n\x0fMessageMetadata\x12\x16\n\x02id\x18\x01 \x01(\x0b\x32\n.MessageID\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cmessage_type\x18\x03 \x01(\t\x12\x34\n\nproperties\x18\x04 \x03(\x0b\x32 .MessageMetadata.PropertiesEntry\x12\x10\n\x08protocol\x18\x05 \x01(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\x12RawMessageMetadata\x12\x16\n\x02id\x18\x01 \x01(\x0b\x32\n.MessageID\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\nproperties\x18\x03 \x03(\x0b\x32#.RawMessageMetadata.PropertiesEntry\x12\x10\n\x08protocol\x18\x04 \x01(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\x05Value\x12 \n\nnull_value\x18\x01 \x01(\x0e\x32\n.NullValueH\x00\x12\x16\n\x0csimple_value\x18\x02 \x01(\tH\x00\x12!\n\rmessage_value\x18\x03 \x01(\x0b\x32\x08.MessageH\x00\x12 \n\nlist_value\x18\x04 \x01(\x0b\x32\n.ListValueH\x00\x42\x06\n\x04kind\"#\n\tListValue\x12\x16\n\x06values\x18\x01 \x03(\x0b\x32\x06.Value\"\xad\x01\n\x07Message\x12!\n\x0fparent_event_id\x18\x03 \x01(\x0b\x32\x08.EventID\x12\"\n\x08metadata\x18\x01 \x01(\x0b\x32\x10.MessageMetadata\x12$\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x14.Message.FieldsEntry\x1a\x35\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\"d\n\nRawMessage\x12!\n\x0fparent_event_id\x18\x03 \x01(\x0b\x32\x08.EventID\x12%\n\x08metadata\x18\x01 \x01(\x0b\x32\x13.RawMessageMetadata\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x0c\"U\n\nAnyMessage\x12\x1b\n\x07message\x18\x01 \x01(\x0b\x32\x08.MessageH\x00\x12\"\n\x0braw_message\x18\x02 \x01(\x0b\x32\x0b.RawMessageH\x00\x42\x06\n\x04kind\"-\n\x0cMessageGroup\x12\x1d\n\x08messages\x18\x01 \x03(\x0b\x32\x0b.AnyMessage\"*\n\x0cMessageBatch\x12\x1a\n\x08messages\x18\x01 \x03(\x0b\x32\x08.Message\"0\n\x0fRawMessageBatch\x12\x1d\n\x08messages\x18\x01 \x03(\x0b\x32\x0b.RawMessage\"2\n\x11MessageGroupBatch\x12\x1d\n\x06groups\x18\x01 \x03(\x0b\x32\r.MessageGroup\"i\n\rRequestStatus\x12%\n\x06status\x18\x01 \x01(\x0e\x32\x15.RequestStatus.Status\x12\x0f\n\x07message\x18\x02 \x01(\t\" \n\x06Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"Y\n\x12\x43omparisonSettings\x12\x19\n\rignore_fields\x18\x01 \x03(\tB\x02\x18\x01\x12(\n\x0f\x66\x61il_unexpected\x18\x02 \x01(\x0e\x32\x0f.FailUnexpected\"/\n\x16RootComparisonSettings\x12\x15\n\rignore_fields\x18\x01 \x03(\t\"\xb3\x01\n\x0bValueFilter\x12#\n\toperation\x18\x01 \x01(\x0e\x32\x10.FilterOperation\x12\x0b\n\x03key\x18\x02 \x01(\x08\x12\x17\n\rsimple_filter\x18\x03 \x01(\tH\x00\x12(\n\x0emessage_filter\x18\x04 \x01(\x0b\x32\x0e.MessageFilterH\x00\x12\'\n\x0blist_filter\x18\x05 \x01(\x0b\x32\x10.ListValueFilterH\x00\x42\x06\n\x04kind\"/\n\x0fListValueFilter\x12\x1c\n\x06values\x18\x01 \x03(\x0b\x32\x0c.ValueFilter\"\xda\x01\n\rMessageFilter\x12\x17\n\x0bmessageType\x18\x01 \x01(\tB\x02\x18\x01\x12\x15\n\tdirection\x18\x02 \x01(\tB\x02\x18\x01\x12*\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x1a.MessageFilter.FieldsEntry\x12\x30\n\x13\x63omparison_settings\x18\x04 \x01(\x0b\x32\x13.ComparisonSettings\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01\"\xf7\x01\n\x0eMetadataFilter\x12>\n\x10property_filters\x18\x01 \x03(\x0b\x32$.MetadataFilter.PropertyFiltersEntry\x1aO\n\x0cSimpleFilter\x12#\n\toperation\x18\x01 \x01(\x0e\x32\x10.FilterOperation\x12\x0b\n\x03key\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x01(\t\x1aT\n\x14PropertyFiltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.MetadataFilter.SimpleFilter:\x02\x38\x01\"\xb0\x01\n\x11RootMessageFilter\x12\x13\n\x0bmessageType\x18\x01 \x01(\t\x12&\n\x0emessage_filter\x18\x02 \x01(\x0b\x32\x0e.MessageFilter\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x12\x34\n\x13\x63omparison_settings\x18\x04 \x01(\x0b\x32\x17.RootComparisonSettings\"\x93\x03\n\nCheckpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x61\n%session_alias_to_direction_checkpoint\x18\x02 \x03(\x0b\x32\x32.Checkpoint.SessionAliasToDirectionCheckpointEntry\x1ai\n&SessionAliasToDirectionCheckpointEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.Checkpoint.DirectionCheckpoint:\x02\x38\x01\x1a\xaa\x01\n\x13\x44irectionCheckpoint\x12W\n\x15\x64irection_to_sequence\x18\x01 \x03(\x0b\x32\x38.Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry\x1a:\n\x18\x44irectionToSequenceEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x15\n\x07\x45ventID\x12\n\n\x02id\x18\x01 \x01(\t\"\x94\x02\n\x05\x45vent\x12\x14\n\x02id\x18\x01 \x01(\x0b\x32\x08.EventID\x12\x1b\n\tparent_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x06status\x18\x05 \x01(\x0e\x32\x0c.EventStatus\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12\x0c\n\x04\x62ody\x18\x08 \x01(\x0c\x12(\n\x14\x61ttached_message_ids\x18\t \x03(\x0b\x32\n.MessageID\"G\n\nEventBatch\x12!\n\x0fparent_event_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12\x16\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x06.Event*\"\n\tDirection\x12\t\n\x05\x46IRST\x10\x00\x12\n\n\x06SECOND\x10\x01*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00*=\n\x0e\x46\x61ilUnexpected\x12\x06\n\x02NO\x10\x00\x12\n\n\x06\x46IELDS\x10\x01\x12\x17\n\x13\x46IELDS_AND_MESSAGES\x10\x02*S\n\x0f\x46ilterOperation\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01\x12\t\n\x05\x45MPTY\x10\x02\x12\r\n\tNOT_EMPTY\x10\x03\x12\x0c\n\x08WILDCARD\x10\x04*&\n\x0b\x45ventStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x42 \n\x1c\x63om.exactpro.th2.common.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIRST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECOND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3330,
  serialized_end=3364,
)
_sym_db.RegisterEnumDescriptor(_DIRECTION)

Direction = enum_type_wrapper.EnumTypeWrapper(_DIRECTION)
_NULLVALUE = _descriptor.EnumDescriptor(
  name='NullValue',
  full_name='NullValue',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NULL_VALUE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3366,
  serialized_end=3393,
)
_sym_db.RegisterEnumDescriptor(_NULLVALUE)

NullValue = enum_type_wrapper.EnumTypeWrapper(_NULLVALUE)
_FAILUNEXPECTED = _descriptor.EnumDescriptor(
  name='FailUnexpected',
  full_name='FailUnexpected',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELDS_AND_MESSAGES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3395,
  serialized_end=3456,
)
_sym_db.RegisterEnumDescriptor(_FAILUNEXPECTED)

FailUnexpected = enum_type_wrapper.EnumTypeWrapper(_FAILUNEXPECTED)
_FILTEROPERATION = _descriptor.EnumDescriptor(
  name='FilterOperation',
  full_name='FilterOperation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EMPTY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WILDCARD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3458,
  serialized_end=3541,
)
_sym_db.RegisterEnumDescriptor(_FILTEROPERATION)

FilterOperation = enum_type_wrapper.EnumTypeWrapper(_FILTEROPERATION)
_EVENTSTATUS = _descriptor.EnumDescriptor(
  name='EventStatus',
  full_name='EventStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3543,
  serialized_end=3581,
)
_sym_db.RegisterEnumDescriptor(_EVENTSTATUS)

EventStatus = enum_type_wrapper.EnumTypeWrapper(_EVENTSTATUS)
FIRST = 0
SECOND = 1
NULL_VALUE = 0
NO = 0
FIELDS = 1
FIELDS_AND_MESSAGES = 2
EQUAL = 0
NOT_EQUAL = 1
EMPTY = 2
NOT_EMPTY = 3
WILDCARD = 4
SUCCESS = 0
FAILED = 1


_REQUESTSTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='RequestStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1494,
  serialized_end=1526,
)
_sym_db.RegisterEnumDescriptor(_REQUESTSTATUS_STATUS)


_CONNECTIONID = _descriptor.Descriptor(
  name='ConnectionID',
  full_name='ConnectionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_alias', full_name='ConnectionID.session_alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=102,
)


_MESSAGEID = _descriptor.Descriptor(
  name='MessageID',
  full_name='MessageID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='MessageID.connection_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='MessageID.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='MessageID.sequence', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsequence', full_name='MessageID.subsequence', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=223,
)


_MESSAGEMETADATA_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='MessageMetadata.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='MessageMetadata.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='MessageMetadata.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=459,
)

_MESSAGEMETADATA = _descriptor.Descriptor(
  name='MessageMetadata',
  full_name='MessageMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='MessageMetadata.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='MessageMetadata.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='MessageMetadata.message_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='MessageMetadata.properties', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='MessageMetadata.protocol', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGEMETADATA_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=459,
)


_RAWMESSAGEMETADATA_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='RawMessageMetadata.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='RawMessageMetadata.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='RawMessageMetadata.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=459,
)

_RAWMESSAGEMETADATA = _descriptor.Descriptor(
  name='RawMessageMetadata',
  full_name='RawMessageMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='RawMessageMetadata.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='RawMessageMetadata.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='RawMessageMetadata.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='RawMessageMetadata.protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RAWMESSAGEMETADATA_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=679,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='null_value', full_name='Value.null_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_value', full_name='Value.simple_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='Value.message_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_value', full_name='Value.list_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='Value.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=682,
  serialized_end=824,
)


_LISTVALUE = _descriptor.Descriptor(
  name='ListValue',
  full_name='ListValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='ListValue.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=861,
)


_MESSAGE_FIELDSENTRY = _descriptor.Descriptor(
  name='FieldsEntry',
  full_name='Message.FieldsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Message.FieldsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Message.FieldsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1037,
)

_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='Message.parent_event_id', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='Message.metadata', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='Message.fields', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGE_FIELDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=1037,
)


_RAWMESSAGE = _descriptor.Descriptor(
  name='RawMessage',
  full_name='RawMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='RawMessage.parent_event_id', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='RawMessage.metadata', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='RawMessage.body', index=2,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1139,
)


_ANYMESSAGE = _descriptor.Descriptor(
  name='AnyMessage',
  full_name='AnyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='AnyMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_message', full_name='AnyMessage.raw_message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='AnyMessage.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1141,
  serialized_end=1226,
)


_MESSAGEGROUP = _descriptor.Descriptor(
  name='MessageGroup',
  full_name='MessageGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='MessageGroup.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1228,
  serialized_end=1273,
)


_MESSAGEBATCH = _descriptor.Descriptor(
  name='MessageBatch',
  full_name='MessageBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='MessageBatch.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1317,
)


_RAWMESSAGEBATCH = _descriptor.Descriptor(
  name='RawMessageBatch',
  full_name='RawMessageBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='RawMessageBatch.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1367,
)


_MESSAGEGROUPBATCH = _descriptor.Descriptor(
  name='MessageGroupBatch',
  full_name='MessageGroupBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='MessageGroupBatch.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1419,
)


_REQUESTSTATUS = _descriptor.Descriptor(
  name='RequestStatus',
  full_name='RequestStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='RequestStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='RequestStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REQUESTSTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1421,
  serialized_end=1526,
)


_COMPARISONSETTINGS = _descriptor.Descriptor(
  name='ComparisonSettings',
  full_name='ComparisonSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_fields', full_name='ComparisonSettings.ignore_fields', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_unexpected', full_name='ComparisonSettings.fail_unexpected', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1528,
  serialized_end=1617,
)


_ROOTCOMPARISONSETTINGS = _descriptor.Descriptor(
  name='RootComparisonSettings',
  full_name='RootComparisonSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_fields', full_name='RootComparisonSettings.ignore_fields', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1666,
)


_VALUEFILTER = _descriptor.Descriptor(
  name='ValueFilter',
  full_name='ValueFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='ValueFilter.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='ValueFilter.key', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_filter', full_name='ValueFilter.simple_filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_filter', full_name='ValueFilter.message_filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_filter', full_name='ValueFilter.list_filter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='ValueFilter.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1669,
  serialized_end=1848,
)


_LISTVALUEFILTER = _descriptor.Descriptor(
  name='ListValueFilter',
  full_name='ListValueFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='ListValueFilter.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1850,
  serialized_end=1897,
)


_MESSAGEFILTER_FIELDSENTRY = _descriptor.Descriptor(
  name='FieldsEntry',
  full_name='MessageFilter.FieldsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='MessageFilter.FieldsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='MessageFilter.FieldsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2059,
  serialized_end=2118,
)

_MESSAGEFILTER = _descriptor.Descriptor(
  name='MessageFilter',
  full_name='MessageFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageType', full_name='MessageFilter.messageType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='MessageFilter.direction', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='MessageFilter.fields', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparison_settings', full_name='MessageFilter.comparison_settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGEFILTER_FIELDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1900,
  serialized_end=2118,
)


_METADATAFILTER_SIMPLEFILTER = _descriptor.Descriptor(
  name='SimpleFilter',
  full_name='MetadataFilter.SimpleFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='MetadataFilter.SimpleFilter.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='MetadataFilter.SimpleFilter.key', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='MetadataFilter.SimpleFilter.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2282,
)

_METADATAFILTER_PROPERTYFILTERSENTRY = _descriptor.Descriptor(
  name='PropertyFiltersEntry',
  full_name='MetadataFilter.PropertyFiltersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='MetadataFilter.PropertyFiltersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='MetadataFilter.PropertyFiltersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2368,
)

_METADATAFILTER = _descriptor.Descriptor(
  name='MetadataFilter',
  full_name='MetadataFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_filters', full_name='MetadataFilter.property_filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATAFILTER_SIMPLEFILTER, _METADATAFILTER_PROPERTYFILTERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2121,
  serialized_end=2368,
)


_ROOTMESSAGEFILTER = _descriptor.Descriptor(
  name='RootMessageFilter',
  full_name='RootMessageFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageType', full_name='RootMessageFilter.messageType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_filter', full_name='RootMessageFilter.message_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_filter', full_name='RootMessageFilter.metadata_filter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparison_settings', full_name='RootMessageFilter.comparison_settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2371,
  serialized_end=2547,
)


_CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY = _descriptor.Descriptor(
  name='SessionAliasToDirectionCheckpointEntry',
  full_name='Checkpoint.SessionAliasToDirectionCheckpointEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Checkpoint.SessionAliasToDirectionCheckpointEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Checkpoint.SessionAliasToDirectionCheckpointEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2780,
)

_CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY = _descriptor.Descriptor(
  name='DirectionToSequenceEntry',
  full_name='Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2895,
  serialized_end=2953,
)

_CHECKPOINT_DIRECTIONCHECKPOINT = _descriptor.Descriptor(
  name='DirectionCheckpoint',
  full_name='Checkpoint.DirectionCheckpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction_to_sequence', full_name='Checkpoint.DirectionCheckpoint.direction_to_sequence', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2783,
  serialized_end=2953,
)

_CHECKPOINT = _descriptor.Descriptor(
  name='Checkpoint',
  full_name='Checkpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Checkpoint.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_alias_to_direction_checkpoint', full_name='Checkpoint.session_alias_to_direction_checkpoint', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY, _CHECKPOINT_DIRECTIONCHECKPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2550,
  serialized_end=2953,
)


_EVENTID = _descriptor.Descriptor(
  name='EventID',
  full_name='EventID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EventID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2955,
  serialized_end=2976,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Event.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='Event.parent_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='Event.start_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='Event.end_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Event.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Event.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Event.type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Event.body', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_message_ids', full_name='Event.attached_message_ids', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3255,
)


_EVENTBATCH = _descriptor.Descriptor(
  name='EventBatch',
  full_name='EventBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='EventBatch.parent_event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='EventBatch.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3257,
  serialized_end=3328,
)

_MESSAGEID.fields_by_name['connection_id'].message_type = _CONNECTIONID
_MESSAGEID.fields_by_name['direction'].enum_type = _DIRECTION
_MESSAGEMETADATA_PROPERTIESENTRY.containing_type = _MESSAGEMETADATA
_MESSAGEMETADATA.fields_by_name['id'].message_type = _MESSAGEID
_MESSAGEMETADATA.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGEMETADATA.fields_by_name['properties'].message_type = _MESSAGEMETADATA_PROPERTIESENTRY
_RAWMESSAGEMETADATA_PROPERTIESENTRY.containing_type = _RAWMESSAGEMETADATA
_RAWMESSAGEMETADATA.fields_by_name['id'].message_type = _MESSAGEID
_RAWMESSAGEMETADATA.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RAWMESSAGEMETADATA.fields_by_name['properties'].message_type = _RAWMESSAGEMETADATA_PROPERTIESENTRY
_VALUE.fields_by_name['null_value'].enum_type = _NULLVALUE
_VALUE.fields_by_name['message_value'].message_type = _MESSAGE
_VALUE.fields_by_name['list_value'].message_type = _LISTVALUE
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['null_value'])
_VALUE.fields_by_name['null_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['simple_value'])
_VALUE.fields_by_name['simple_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['message_value'])
_VALUE.fields_by_name['message_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['list_value'])
_VALUE.fields_by_name['list_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_LISTVALUE.fields_by_name['values'].message_type = _VALUE
_MESSAGE_FIELDSENTRY.fields_by_name['value'].message_type = _VALUE
_MESSAGE_FIELDSENTRY.containing_type = _MESSAGE
_MESSAGE.fields_by_name['parent_event_id'].message_type = _EVENTID
_MESSAGE.fields_by_name['metadata'].message_type = _MESSAGEMETADATA
_MESSAGE.fields_by_name['fields'].message_type = _MESSAGE_FIELDSENTRY
_RAWMESSAGE.fields_by_name['parent_event_id'].message_type = _EVENTID
_RAWMESSAGE.fields_by_name['metadata'].message_type = _RAWMESSAGEMETADATA
_ANYMESSAGE.fields_by_name['message'].message_type = _MESSAGE
_ANYMESSAGE.fields_by_name['raw_message'].message_type = _RAWMESSAGE
_ANYMESSAGE.oneofs_by_name['kind'].fields.append(
  _ANYMESSAGE.fields_by_name['message'])
_ANYMESSAGE.fields_by_name['message'].containing_oneof = _ANYMESSAGE.oneofs_by_name['kind']
_ANYMESSAGE.oneofs_by_name['kind'].fields.append(
  _ANYMESSAGE.fields_by_name['raw_message'])
_ANYMESSAGE.fields_by_name['raw_message'].containing_oneof = _ANYMESSAGE.oneofs_by_name['kind']
_MESSAGEGROUP.fields_by_name['messages'].message_type = _ANYMESSAGE
_MESSAGEBATCH.fields_by_name['messages'].message_type = _MESSAGE
_RAWMESSAGEBATCH.fields_by_name['messages'].message_type = _RAWMESSAGE
_MESSAGEGROUPBATCH.fields_by_name['groups'].message_type = _MESSAGEGROUP
_REQUESTSTATUS.fields_by_name['status'].enum_type = _REQUESTSTATUS_STATUS
_REQUESTSTATUS_STATUS.containing_type = _REQUESTSTATUS
_COMPARISONSETTINGS.fields_by_name['fail_unexpected'].enum_type = _FAILUNEXPECTED
_VALUEFILTER.fields_by_name['operation'].enum_type = _FILTEROPERATION
_VALUEFILTER.fields_by_name['message_filter'].message_type = _MESSAGEFILTER
_VALUEFILTER.fields_by_name['list_filter'].message_type = _LISTVALUEFILTER
_VALUEFILTER.oneofs_by_name['kind'].fields.append(
  _VALUEFILTER.fields_by_name['simple_filter'])
_VALUEFILTER.fields_by_name['simple_filter'].containing_oneof = _VALUEFILTER.oneofs_by_name['kind']
_VALUEFILTER.oneofs_by_name['kind'].fields.append(
  _VALUEFILTER.fields_by_name['message_filter'])
_VALUEFILTER.fields_by_name['message_filter'].containing_oneof = _VALUEFILTER.oneofs_by_name['kind']
_VALUEFILTER.oneofs_by_name['kind'].fields.append(
  _VALUEFILTER.fields_by_name['list_filter'])
_VALUEFILTER.fields_by_name['list_filter'].containing_oneof = _VALUEFILTER.oneofs_by_name['kind']
_LISTVALUEFILTER.fields_by_name['values'].message_type = _VALUEFILTER
_MESSAGEFILTER_FIELDSENTRY.fields_by_name['value'].message_type = _VALUEFILTER
_MESSAGEFILTER_FIELDSENTRY.containing_type = _MESSAGEFILTER
_MESSAGEFILTER.fields_by_name['fields'].message_type = _MESSAGEFILTER_FIELDSENTRY
_MESSAGEFILTER.fields_by_name['comparison_settings'].message_type = _COMPARISONSETTINGS
_METADATAFILTER_SIMPLEFILTER.fields_by_name['operation'].enum_type = _FILTEROPERATION
_METADATAFILTER_SIMPLEFILTER.containing_type = _METADATAFILTER
_METADATAFILTER_PROPERTYFILTERSENTRY.fields_by_name['value'].message_type = _METADATAFILTER_SIMPLEFILTER
_METADATAFILTER_PROPERTYFILTERSENTRY.containing_type = _METADATAFILTER
_METADATAFILTER.fields_by_name['property_filters'].message_type = _METADATAFILTER_PROPERTYFILTERSENTRY
_ROOTMESSAGEFILTER.fields_by_name['message_filter'].message_type = _MESSAGEFILTER
_ROOTMESSAGEFILTER.fields_by_name['metadata_filter'].message_type = _METADATAFILTER
_ROOTMESSAGEFILTER.fields_by_name['comparison_settings'].message_type = _ROOTCOMPARISONSETTINGS
_CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY.fields_by_name['value'].message_type = _CHECKPOINT_DIRECTIONCHECKPOINT
_CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY.containing_type = _CHECKPOINT
_CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY.containing_type = _CHECKPOINT_DIRECTIONCHECKPOINT
_CHECKPOINT_DIRECTIONCHECKPOINT.fields_by_name['direction_to_sequence'].message_type = _CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY
_CHECKPOINT_DIRECTIONCHECKPOINT.containing_type = _CHECKPOINT
_CHECKPOINT.fields_by_name['session_alias_to_direction_checkpoint'].message_type = _CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY
_EVENT.fields_by_name['id'].message_type = _EVENTID
_EVENT.fields_by_name['parent_id'].message_type = _EVENTID
_EVENT.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['status'].enum_type = _EVENTSTATUS
_EVENT.fields_by_name['attached_message_ids'].message_type = _MESSAGEID
_EVENTBATCH.fields_by_name['parent_event_id'].message_type = _EVENTID
_EVENTBATCH.fields_by_name['events'].message_type = _EVENT
DESCRIPTOR.message_types_by_name['ConnectionID'] = _CONNECTIONID
DESCRIPTOR.message_types_by_name['MessageID'] = _MESSAGEID
DESCRIPTOR.message_types_by_name['MessageMetadata'] = _MESSAGEMETADATA
DESCRIPTOR.message_types_by_name['RawMessageMetadata'] = _RAWMESSAGEMETADATA
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['ListValue'] = _LISTVALUE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['RawMessage'] = _RAWMESSAGE
DESCRIPTOR.message_types_by_name['AnyMessage'] = _ANYMESSAGE
DESCRIPTOR.message_types_by_name['MessageGroup'] = _MESSAGEGROUP
DESCRIPTOR.message_types_by_name['MessageBatch'] = _MESSAGEBATCH
DESCRIPTOR.message_types_by_name['RawMessageBatch'] = _RAWMESSAGEBATCH
DESCRIPTOR.message_types_by_name['MessageGroupBatch'] = _MESSAGEGROUPBATCH
DESCRIPTOR.message_types_by_name['RequestStatus'] = _REQUESTSTATUS
DESCRIPTOR.message_types_by_name['ComparisonSettings'] = _COMPARISONSETTINGS
DESCRIPTOR.message_types_by_name['RootComparisonSettings'] = _ROOTCOMPARISONSETTINGS
DESCRIPTOR.message_types_by_name['ValueFilter'] = _VALUEFILTER
DESCRIPTOR.message_types_by_name['ListValueFilter'] = _LISTVALUEFILTER
DESCRIPTOR.message_types_by_name['MessageFilter'] = _MESSAGEFILTER
DESCRIPTOR.message_types_by_name['MetadataFilter'] = _METADATAFILTER
DESCRIPTOR.message_types_by_name['RootMessageFilter'] = _ROOTMESSAGEFILTER
DESCRIPTOR.message_types_by_name['Checkpoint'] = _CHECKPOINT
DESCRIPTOR.message_types_by_name['EventID'] = _EVENTID
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EventBatch'] = _EVENTBATCH
DESCRIPTOR.enum_types_by_name['Direction'] = _DIRECTION
DESCRIPTOR.enum_types_by_name['NullValue'] = _NULLVALUE
DESCRIPTOR.enum_types_by_name['FailUnexpected'] = _FAILUNEXPECTED
DESCRIPTOR.enum_types_by_name['FilterOperation'] = _FILTEROPERATION
DESCRIPTOR.enum_types_by_name['EventStatus'] = _EVENTSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectionID = _reflection.GeneratedProtocolMessageType('ConnectionID', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONID,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:ConnectionID)
  })
_sym_db.RegisterMessage(ConnectionID)

MessageID = _reflection.GeneratedProtocolMessageType('MessageID', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEID,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageID)
  })
_sym_db.RegisterMessage(MessageID)

MessageMetadata = _reflection.GeneratedProtocolMessageType('MessageMetadata', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MESSAGEMETADATA_PROPERTIESENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:MessageMetadata.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _MESSAGEMETADATA,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageMetadata)
  })
_sym_db.RegisterMessage(MessageMetadata)
_sym_db.RegisterMessage(MessageMetadata.PropertiesEntry)

RawMessageMetadata = _reflection.GeneratedProtocolMessageType('RawMessageMetadata', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RAWMESSAGEMETADATA_PROPERTIESENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:RawMessageMetadata.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _RAWMESSAGEMETADATA,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RawMessageMetadata)
  })
_sym_db.RegisterMessage(RawMessageMetadata)
_sym_db.RegisterMessage(RawMessageMetadata.PropertiesEntry)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:Value)
  })
_sym_db.RegisterMessage(Value)

ListValue = _reflection.GeneratedProtocolMessageType('ListValue', (_message.Message,), {
  'DESCRIPTOR' : _LISTVALUE,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:ListValue)
  })
_sym_db.RegisterMessage(ListValue)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {

  'FieldsEntry' : _reflection.GeneratedProtocolMessageType('FieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MESSAGE_FIELDSENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:Message.FieldsEntry)
    })
  ,
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:Message)
  })
_sym_db.RegisterMessage(Message)
_sym_db.RegisterMessage(Message.FieldsEntry)

RawMessage = _reflection.GeneratedProtocolMessageType('RawMessage', (_message.Message,), {
  'DESCRIPTOR' : _RAWMESSAGE,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RawMessage)
  })
_sym_db.RegisterMessage(RawMessage)

AnyMessage = _reflection.GeneratedProtocolMessageType('AnyMessage', (_message.Message,), {
  'DESCRIPTOR' : _ANYMESSAGE,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:AnyMessage)
  })
_sym_db.RegisterMessage(AnyMessage)

MessageGroup = _reflection.GeneratedProtocolMessageType('MessageGroup', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEGROUP,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageGroup)
  })
_sym_db.RegisterMessage(MessageGroup)

MessageBatch = _reflection.GeneratedProtocolMessageType('MessageBatch', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEBATCH,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageBatch)
  })
_sym_db.RegisterMessage(MessageBatch)

RawMessageBatch = _reflection.GeneratedProtocolMessageType('RawMessageBatch', (_message.Message,), {
  'DESCRIPTOR' : _RAWMESSAGEBATCH,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RawMessageBatch)
  })
_sym_db.RegisterMessage(RawMessageBatch)

MessageGroupBatch = _reflection.GeneratedProtocolMessageType('MessageGroupBatch', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEGROUPBATCH,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageGroupBatch)
  })
_sym_db.RegisterMessage(MessageGroupBatch)

RequestStatus = _reflection.GeneratedProtocolMessageType('RequestStatus', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSTATUS,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RequestStatus)
  })
_sym_db.RegisterMessage(RequestStatus)

ComparisonSettings = _reflection.GeneratedProtocolMessageType('ComparisonSettings', (_message.Message,), {
  'DESCRIPTOR' : _COMPARISONSETTINGS,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:ComparisonSettings)
  })
_sym_db.RegisterMessage(ComparisonSettings)

RootComparisonSettings = _reflection.GeneratedProtocolMessageType('RootComparisonSettings', (_message.Message,), {
  'DESCRIPTOR' : _ROOTCOMPARISONSETTINGS,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RootComparisonSettings)
  })
_sym_db.RegisterMessage(RootComparisonSettings)

ValueFilter = _reflection.GeneratedProtocolMessageType('ValueFilter', (_message.Message,), {
  'DESCRIPTOR' : _VALUEFILTER,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:ValueFilter)
  })
_sym_db.RegisterMessage(ValueFilter)

ListValueFilter = _reflection.GeneratedProtocolMessageType('ListValueFilter', (_message.Message,), {
  'DESCRIPTOR' : _LISTVALUEFILTER,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:ListValueFilter)
  })
_sym_db.RegisterMessage(ListValueFilter)

MessageFilter = _reflection.GeneratedProtocolMessageType('MessageFilter', (_message.Message,), {

  'FieldsEntry' : _reflection.GeneratedProtocolMessageType('FieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MESSAGEFILTER_FIELDSENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:MessageFilter.FieldsEntry)
    })
  ,
  'DESCRIPTOR' : _MESSAGEFILTER,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MessageFilter)
  })
_sym_db.RegisterMessage(MessageFilter)
_sym_db.RegisterMessage(MessageFilter.FieldsEntry)

MetadataFilter = _reflection.GeneratedProtocolMessageType('MetadataFilter', (_message.Message,), {

  'SimpleFilter' : _reflection.GeneratedProtocolMessageType('SimpleFilter', (_message.Message,), {
    'DESCRIPTOR' : _METADATAFILTER_SIMPLEFILTER,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:MetadataFilter.SimpleFilter)
    })
  ,

  'PropertyFiltersEntry' : _reflection.GeneratedProtocolMessageType('PropertyFiltersEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATAFILTER_PROPERTYFILTERSENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:MetadataFilter.PropertyFiltersEntry)
    })
  ,
  'DESCRIPTOR' : _METADATAFILTER,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:MetadataFilter)
  })
_sym_db.RegisterMessage(MetadataFilter)
_sym_db.RegisterMessage(MetadataFilter.SimpleFilter)
_sym_db.RegisterMessage(MetadataFilter.PropertyFiltersEntry)

RootMessageFilter = _reflection.GeneratedProtocolMessageType('RootMessageFilter', (_message.Message,), {
  'DESCRIPTOR' : _ROOTMESSAGEFILTER,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:RootMessageFilter)
  })
_sym_db.RegisterMessage(RootMessageFilter)

Checkpoint = _reflection.GeneratedProtocolMessageType('Checkpoint', (_message.Message,), {

  'SessionAliasToDirectionCheckpointEntry' : _reflection.GeneratedProtocolMessageType('SessionAliasToDirectionCheckpointEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:Checkpoint.SessionAliasToDirectionCheckpointEntry)
    })
  ,

  'DirectionCheckpoint' : _reflection.GeneratedProtocolMessageType('DirectionCheckpoint', (_message.Message,), {

    'DirectionToSequenceEntry' : _reflection.GeneratedProtocolMessageType('DirectionToSequenceEntry', (_message.Message,), {
      'DESCRIPTOR' : _CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY,
      '__module__' : 'th2_grpc_common.common_pb2'
      # @@protoc_insertion_point(class_scope:Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry)
      })
    ,
    'DESCRIPTOR' : _CHECKPOINT_DIRECTIONCHECKPOINT,
    '__module__' : 'th2_grpc_common.common_pb2'
    # @@protoc_insertion_point(class_scope:Checkpoint.DirectionCheckpoint)
    })
  ,
  'DESCRIPTOR' : _CHECKPOINT,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:Checkpoint)
  })
_sym_db.RegisterMessage(Checkpoint)
_sym_db.RegisterMessage(Checkpoint.SessionAliasToDirectionCheckpointEntry)
_sym_db.RegisterMessage(Checkpoint.DirectionCheckpoint)
_sym_db.RegisterMessage(Checkpoint.DirectionCheckpoint.DirectionToSequenceEntry)

EventID = _reflection.GeneratedProtocolMessageType('EventID', (_message.Message,), {
  'DESCRIPTOR' : _EVENTID,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:EventID)
  })
_sym_db.RegisterMessage(EventID)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:Event)
  })
_sym_db.RegisterMessage(Event)

EventBatch = _reflection.GeneratedProtocolMessageType('EventBatch', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCH,
  '__module__' : 'th2_grpc_common.common_pb2'
  # @@protoc_insertion_point(class_scope:EventBatch)
  })
_sym_db.RegisterMessage(EventBatch)


DESCRIPTOR._options = None
_MESSAGEMETADATA_PROPERTIESENTRY._options = None
_RAWMESSAGEMETADATA_PROPERTIESENTRY._options = None
_MESSAGE_FIELDSENTRY._options = None
_COMPARISONSETTINGS.fields_by_name['ignore_fields']._options = None
_MESSAGEFILTER_FIELDSENTRY._options = None
_MESSAGEFILTER.fields_by_name['messageType']._options = None
_MESSAGEFILTER.fields_by_name['direction']._options = None
_METADATAFILTER_PROPERTYFILTERSENTRY._options = None
_CHECKPOINT_SESSIONALIASTODIRECTIONCHECKPOINTENTRY._options = None
_CHECKPOINT_DIRECTIONCHECKPOINT_DIRECTIONTOSEQUENCEENTRY._options = None
# @@protoc_insertion_point(module_scope)
